@@ -19,9 +19,11 @@ def get_up_token(cjdg_access_token):
     logger.error(params)
 
 
-def request_accesstoken(acc: str, pwd: str) -> str:
+def request_accesstoken(acc: str, pwd: str, safe=False, domain=False, **kwargs) -> str:
     # 请求accesstooke函数
-    url = "http://bms.microc.cn/shopguide/api/auth/logon"
+    protocol = "https" if safe else "http"
+    domain_name = "bms.chaojidaogou.com" if domain else "it.xxynet.com"
+    url = f"{protocol}://{domain_name}/shopguide/api/auth/logon"
     data = {}
     data["loginName"] = acc
     data["password"] = pwd
@@ -32,9 +34,11 @@ def request_accesstoken(acc: str, pwd: str) -> str:
         return accessToken
 
 
-def request_accesstoken_pc(acc: str, pwd: str) -> str:
+def request_accesstoken_pc(acc: str, pwd: str, safe=False, domain=False, **kwargs) -> str:
     # 请求accesstooke函数
-    url = "http://bms.microc.cn/shopguide/api/auth/logonweb"
+    protocol = "https" if safe else "http"
+    domain_name = "bms.chaojidaogou.com" if domain else "it.xxynet.com"
+    url = f"{protocol}://{domain_name}/shopguide/api/auth/logonweb"
     data = {}
     data["loginName"] = acc
     data["password"] = pwd
@@ -57,26 +61,22 @@ class base:
         self.app_secret = app_secret
 
     def request(self, api_name=None, method="GET",
-                url=None, api_prefix="api/", safe=False, **kwargs):
+                url=None, api_prefix="api/", safe=False, domain=False,host=False,convert=False, **kwargs):
         protocol = "https" if safe else "http"
-        host_name = f"{protocol}://bms.microc.cn/shopguide/"
-        # host_name = "http://test.xxynet.com/shopguide/api/"
+        domain_name = "bms.chaojidaogou.com" if domain else "it.xxynet.com"
+        host_name = f"{protocol}://{domain_name}/shopguide/" if host else f"{protocol}://{domain_name}"
         if not url:
             # url is None:generate url use hostname+api_prefix+apiname
-            url = f"{host_name}{api_prefix}{api_name}"
+            url = f"{host_name}{api_prefix}{api_name}" if convert else f"{host_name}{api_name}"
         # params
         params = kwargs.get("params", {})
-        params["accessToken"] = self.token
+        params["accessToken"] = self.token 
         params["appSecret"] = self.app_secret
         kwargs["params"] = params
         # cookies
         cookies = kwargs.get("cookies", {})
         cookies["accessToken"] = self.token
         kwargs["cookies"] = cookies
-        # other
-        # kwargs["headers"] = kwargs.get("headers", {})
-        # kwargs["json"] = kwargs.get("json", {})
-        # kwargs["data"] = kwargs.get("data", {})
         logger.debug(url)
         logger.debug(kwargs)
         response = requests.request(
@@ -85,11 +85,6 @@ class base:
             **kwargs
         )
         if response.status_code == 200:
-            # logger.debug({
-            #     "url": url,
-            #     "self.token": self.token,
-            #     "response": response.text,
-            # })
             return self.response(response.json())
         logger.error(response.text)
 
