@@ -9,9 +9,11 @@ import requests
 import json
 
 
-def request_accesstoken(acc: str, pwd: str) -> str:
+def request_accesstoken(acc: str, pwd: str, safe=False, domain=False, **kwargs) -> str:
     # 请求accesstooke函数
-    url = "http://bms.microc.cn/shopguide/api/auth/logonweb"
+    protocol = "https" if safe else "http"
+    domain_name = "bms.chaojidaogou.com" if domain else "it.xxynet.com"
+    url = f"{protocol}://{domain_name}/shopguide/api/auth/logonweb"
     data = {}
     data["loginName"] = acc
     data["password"] = pwd
@@ -28,10 +30,12 @@ class base:
         self.token = token
         self.app_secret = app_secret
 
-    def request(self, api_name=None, params={}, data={}, json={}, headers={}, method="GET", url=None):
+    def request(self, api_name=None, params={}, data={}, json={}, headers={}, method="GET", url=None, safe=False, domain=False, **kwargs):
         # host_name = "http://bms.microc.cn/shopguide/api/"
         # host_name = "http://test.xxynet.com/shopguide/api/"
-        host_name = "http://bms.chaojidaogou.com/shopguide/api/"
+        protocol = "https" if safe else "http"
+        domain_name = "bms.chaojidaogou.com" if domain else "it.xxynet.com"
+        host_name = f"{protocol}://{domain_name}/shopguide/api/"
         if not url:
             if host_name not in api_name:
                 url = f"{host_name}{api_name}"
